Learn R Programming

SurrogateRegression (version 0.6.0.1)

WaldBNLS: Wald Test via Least Squares.

Description

Performs a Wald test of the null hypothesis that a subset of the regression parameters for the target outcome are zero.

Usage

WaldBNLS(t, s, X, is_zero)

Value

A numeric vector containing the Wald statistic, the degrees of freedom, and a p-value.

Arguments

t

Target outcome vector.

s

Surrogate outcome vector.

X

Model matrix.

is_zero

Logical vector, with as many entires as columns in the target model matrix, indicating which columns have coefficient zero under the null.