Learn R Programming

SurrogateRegression (version 0.6.0.1)

vcov.bnr: Extract Covariance Matrix from Bivariate Normal Regression Model

Description

Returns the either the estimated covariance matrix of the outcome, the information matrix for regression coefficients, or the information matrix for covariance parameters.

Usage

# S3 method for bnr
vcov(object, ..., type = "Regression", inv = FALSE)

Arguments

object

bnr object.

...

Unused.

type

Select "Covariance","Outcome",or "Regression". Default is "Regression".

inv

Invert the covariance matrix? Default is FALSE.