Returns the either the estimated covariance matrix of the outcome, the information matrix for regression coefficients, or the information matrix for covariance parameters.
# S3 method for bnr
vcov(object, ..., type = "Regression", inv = FALSE)bnr object.
Unused.
Select "Covariance","Outcome",or "Regression". Default is "Regression".
Invert the covariance matrix? Default is FALSE.